{# TEMPLATE VAR SETTINGS #}
{%- set url_root = pathto('', 1) %}
{%- if url_root == '#' %}{% set url_root = '' %}{% endif %}
{%- if not embedded and docstitle %}
  {%- set titlesuffix = " &mdash; "|safe + docstitle|e %}
{%- else %}
  {%- set titlesuffix = "" %}
{%- endif %}
{%- set lang_attr = 'en' if language == None else (language | replace('_', '-')) %}

<!DOCTYPE html>
<!--[if IE 8]><html class="no-js lt-ie9" lang="{{ lang_attr }}" > <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="{{ lang_attr }}" > <!--<![endif]-->
<head>
  <meta charset="utf-8">
  {{ metatags }}
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  {% block htmltitle %}
  <title>{{ title|striptags|e }}{{ titlesuffix }}</title>
  {% endblock %}

  {# FAVICON #}
  {% if favicon %}
    <link rel="shortcut icon" href="{{ pathto('_static/' + favicon, 1) }}"/>
  {% endif %}
  {# CANONICAL URL #}
  {% if theme_canonical_url %}
    <link rel="canonical" href="{{ theme_canonical_url }}{{ pagename }}.html"/>
  {% endif %}

  {# JAVASCRIPTS #}
  {%- if not embedded %}
  {# XXX Sphinx 1.8.0 made this an external js-file, quick fix until we refactor the template to inherert more blocks directly from sphinx #}
    {% if sphinx_version >= "1.8.0" %}
      <script type="text/javascript" id="documentation_options" data-url_root="{{ pathto('', 1) }}" src="{{ pathto('_static/documentation_options.js', 1) }}"></script>
      {%- for scriptfile in script_files %}
        {{ js_tag(scriptfile) }}
      {%- endfor %}
    {% else %}
      <script type="text/javascript">
          var DOCUMENTATION_OPTIONS = {
              URL_ROOT:'{{ url_root }}',
              VERSION:'{{ release|e }}',
              LANGUAGE:'{{ language }}',
              COLLAPSE_INDEX:false,
              FILE_SUFFIX:'{{ '' if no_search_suffix else file_suffix }}',
              HAS_SOURCE:  {{ has_source|lower }},
              SOURCELINK_SUFFIX: '{{ sourcelink_suffix }}'
          };
      </script>
      {%- for scriptfile in script_files %}
        <script type="text/javascript" src="{{ pathto(scriptfile, 1) }}"></script>
      {%- endfor %}
    {% endif %}

    {# OPENSEARCH #}
    {%- if use_opensearch %}
    <link rel="search" type="application/opensearchdescription+xml"
          title="{% trans docstitle=docstitle|e %}Search within {{ docstitle }}{% endtrans %}"
          href="{{ pathto('_static/opensearch.xml', 1) }}"/>
    {%- endif %}

    
    {# AUTH #}
    {% if theme_docs_auth|tobool %}
    <script type="text/javascript">
      localStorage.setItem('docsAuth', 'true');
    </script>
    {% else %}
    <script type="text/javascript">
      localStorage.setItem('docsAuth', '');
    </script>
    {% endif %}
  {%- endif %}

  {# CSS #}
  <link rel="stylesheet" href="{{ pathto('_static/' + style, 1) }}" type="text/css" />
  <!-- <link rel="stylesheet" href="{{ pathto('_static/pygments.css', 1) }}" type="text/css" /> -->
  {%- for css in css_files %}
    {%- if css|attr("rel") %}
  <link rel="{{ css.rel }}" href="{{ pathto(css.filename, 1) }}" type="text/css"{% if css.title is not none %} title="{{ css.title }}"{% endif %} />
    {%- else %}
  <link rel="stylesheet" href="{{ pathto(css, 1) }}" type="text/css" />
    {%- endif %}
  {%- endfor %}

  {%- for cssfile in extra_css_files %}
    <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
  {%- endfor %}

  {%- block linktags %}
    {%- if hasdoc('about') %}
    <link rel="author" title="{{ _('About these documents') }}" href="{{ pathto('about') }}" />
    {%- endif %}
    {%- if hasdoc('genindex') %}
    <link rel="index" title="{{ _('Index') }}" href="{{ pathto('genindex') }}" />
    {%- endif %}
    {%- if hasdoc('search') %}
    <link rel="search" title="{{ _('Search') }}" href="{{ pathto('search') }}" />
    {%- endif %}
    {%- if hasdoc('copyright') %}
    <link rel="copyright" title="{{ _('Copyright') }}" href="{{ pathto('copyright') }}" />
    {%- endif %}
    {%- if next %}
    <link rel="next" title="{{ next.title|striptags|e }}" href="{{ next.link|e }}" />
    {%- endif %}
    {%- if prev %}
    <link rel="prev" title="{{ prev.title|striptags|e }}" href="{{ prev.link|e }}" />
    {%- endif %}
  {%- endblock %}
  {%- block extrahead %} {% endblock %}
</head>

<body id='root'>
  {%include "header.html"%}
  {% block extrabody %} {% endblock %}
  <div class="enos-doc">

    {# SIDE NAV, TOGGLES ON MOBILE #}
    <nav data-toggle="enos-nav-shift" class="enos-doc-side">
    {%include "side.html"%}
    </nav>

    <section data-toggle="enos-nav-shift" class="enos-doc-content">
      <div class="enos-doc-content-body">
        {%- block content %}
          {% if theme_style_external_links|tobool %}
          <div class="rst-content style-external-links">
          {% else %}
          <div class="rst-content">
          {% endif %}
            <div role="main" class="document" itemscope="itemscope" itemtype="http://schema.org/Article">
            {%- block document %}
            <div itemprop="articleBody">
              {% include "breadcrumbs.html" %}
              {% block body %}{% endblock %}
            </div>
            {% if self.comments()|trim %}
            <div class="articleComments">
              {% block comments %}{% endblock %}
            </div>
            {% endif%}
            </div>
            {%- endblock %}
            {% include "footer.html" %}
          </div>
        {%- endblock %}
        <div class="enos-doc-local-toc">
          <div class="toc">
            {{ toc }}
          </div>
        </div>
      </div>
      <!-- footer -->
      {%- block footer %} {% endblock %}

    {%include "gfooter.html"%}
    </section>

  </div>
  <!-- if you are developing this theme, please change next line to  -->
  <!-- <script type="text/javascript" src="{{ pathto('_static/js/theme.js', 1) }}"></script> -->
  <!-- end if -->
 <script type="text/javascript" src="{{ pathto('_static/js/theme.a0161e9ae58bb386e19a.js', 1) }}"></script>

</body>
</html>
