<footer>
  {% if (theme_prev_next_buttons_location == 'bottom' or theme_prev_next_buttons_location == 'both') and (next or prev) %}
    <div class="enos-footer-nav" role="navigation" aria-label="footer navigation">
      {% if prev %}
        <a href="{{ prev.link|e }}" class="prev" title="{{ prev.title|striptags|e }}" accesskey="p" rel="prev"><span class="icon-right"></span> {{ _('Previous') }}</a>
      {% endif %}
      {% if next %}
        <a href="{{ next.link|e }}" class="next" title="{{ next.title|striptags|e }}" accesskey="n" rel="next">{{ _('Next') }} <span class="icon-right"></span></a>
      {% endif %}
    </div>
  {% endif %}

  {%- block extrafooter %} {% endblock %}

</footer>

